﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace Competition
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        Game g;
        public MainWindow()
        {
            InitializeComponent();
        }

        private async void startClick(object sender, RoutedEventArgs e)
        {
            g = new Game(adresaBox.Text);
            (sender as Button).Content = "začít novou hru";
            await g.Start();
            DrawGame();
        }

        private void DrawGame()
        {
            gamePlac.Children.Clear();
            for (int x = 0; x < 10; x++)
            {
                for (int y = 0; y < 10; y++)
                {
                    Rectangle img = new Rectangle();
                    img.Width = gamePlac.Width / 10; img.Height = gamePlac.Height / 10;
                    Canvas.SetLeft(img, x * img.Width);
                    Canvas.SetTop(img, y * img.Height);
                    var pole = (Pole)g.Plan.Except(g.Plan.OfType<Hrac>()).FirstOrDefault(i => i.X == x && i.Y == y);
                    if (pole == null)
                    {
                        //prazdne
                        img.Fill = new SolidColorBrush(Colors.White);
                    }
                    if (pole is Zed)
                    {
                        img.Fill = new SolidColorBrush(Colors.Red);
                        gamePlac.Children.Add(img);
                    }
                    if (pole is Zakladna)
                    {
                        Zakladna z = pole as Zakladna;
                        img.Fill = new SolidColorBrush(z.Mine?Colors.Green:Colors.Blue);
                        gamePlac.Children.Add(img);
                    }
                    if (pole is Poklad)
                    {
                        Poklad p = pole as Poklad;
                        img.Fill = new VisualBrush(new TextBlock() { Text = p.Hodnota.ToString(), Background = new SolidColorBrush(Colors.Orange), VerticalAlignment = VerticalAlignment.Stretch, HorizontalAlignment = HorizontalAlignment.Stretch });
                        gamePlac.Children.Add(img);
                   
                    }
                   
                    
                }
            }
            foreach(var p in g.Plan.OfType<Hrac>())
            {
                Rectangle img = new Rectangle();
                img.Width = gamePlac.Width / 10; img.Height = gamePlac.Height / 10;
                Canvas.SetLeft(img, p.X * img.Width);
                Canvas.SetTop(img, p.Y * img.Height);
                img.Fill = new VisualBrush(new TextBlock() { Text = "hrac", Background = new SolidColorBrush(p.Mine ? Colors.Green : Colors.Blue), VerticalAlignment = VerticalAlignment.Stretch, HorizontalAlignment = HorizontalAlignment.Stretch });
                gamePlac.Children.Add(img);
                if (p.Mine)
                {
                    ziskanypoklad.Text = p.Celkem.ToString();
                    nesenypoklad.Text = p.Poklad.ToString();
                }
            }

            tahu.Text = g.tahu.ToString() + "/" + g.tahuCelkem.ToString();
        }

        private async void Window_KeyUp(object sender, KeyEventArgs e)
        {
            switch(e.Key)
            {
                case Key.Up:
                    if (!await g.Tah(Game.TahOpt.N))
                        CantExc();
                    DrawGame();
                    break;
                case Key.Down:
                    if (!await g.Tah(Game.TahOpt.D))
                        CantExc();
                    DrawGame();
                    break;
                case Key.Left:
                    if (!await g.Tah(Game.TahOpt.L))
                        CantExc();
                    DrawGame();
                    break;
                case Key.Right:
                    if (!await g.Tah(Game.TahOpt.P))
                        CantExc();
                    DrawGame();
                    break;
            }
            if (g.GameEnded)
                MessageBox.Show(g.GameEndedText);
        }

        private void CantExc()
        {
            MessageBox.Show("Tah nelze provést");
        }

        private async void PClick(object sender, RoutedEventArgs e)
        {
            if (!await g.Tah(Game.TahOpt.P))
                        CantExc();
            DrawGame();
        }
        private async void DClick(object sender, RoutedEventArgs e)
        {
            if (!await g.Tah(Game.TahOpt.D))
                        CantExc(); DrawGame();
        }
        private async void LClick(object sender, RoutedEventArgs e)
        {
            if (!await g.Tah(Game.TahOpt.L))
                        CantExc();
            DrawGame();
        }
        private async void NClick(object sender, RoutedEventArgs e)
        {
            if (!await g.Tah(Game.TahOpt.N))
                        CantExc();
            DrawGame();
        }
        AIGame aiGame = new AIGame();
        private async void startAI(object sender, RoutedEventArgs e)
        {
            board.Visibility = Visibility.Collapsed;
            g = new Game(adresaBox.Text);
            (sender as Button).Content = "začít novou hru s AI";
            await g.Start();
            aiGame = new AIGame();
            aiGame.g = g;
            await aiGame.Play();

           // DrawGame();
        }

        private async void Button_Click(object sender, RoutedEventArgs e)
        {
            await g.Tah(aiGame.GetNextStepTowardsTreasure());
            DrawGame();
        }
    }
}
